@@ -1,4 +1,4 @@
-(function($){
+;!(function($){
     $(document).ready(function(){
         $(".django-tabbed-changeform-admin-content").each(function(index, element){
             var content_wrapper = $(this);
@@ -19,4 +19,4 @@
         $(".django-tabbed-changeform-admin-tabs").tabs({
         });
     });
-})(jQuery);
\ No newline at end of file
+})(jQuery);
